@@ -5,8 +5,6 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
+from frozendict import frozendict
 
-
-class HashableDict(dict):
-    def __hash__(self):
-        return hash(tuple(sorted(self.items())))
+HashableDict = frozendict
